[![Build Status](https://travis-ci.org/mjirik/ndnoise.svg?branch=master)](https://travis-ci.org/mjirik/ndnoise)
[![Coverage Status](https://coveralls.io/repos/github/mjirik/ndnoise/badge.svg)](https://coveralls.io/github/mjirik/ndnoise)

# ndnoise
Noise generator


# References

[Noise function and map generation](http://www.redblobgames.com/articles/noise/introduction.html)

perlin - clasic noise
simplex - better noise

opensimplex - open 